@@ -27,6 +27,7 @@
 class QComboBox;
 
 class Budget;
+class Currency;
 class EqonomizeValueEdit;
 
 class CurrencyConversionDialog : public QDialog {
@@ -52,6 +53,10 @@ class CurrencyConversionDialog : public QDialog {
 		void convertTo();
 		void convert();
 
+	signals:
+
+		void exchangeRateUpdateRequest(Currency*, Currency*);
+
 };
 
 #endif
